==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/StackedLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedLineSeriesDescription } from "./StackedLineSeriesDescription";
/**
 * @hidden
 */
export let StackedLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedLineSeriesDescriptionMetadata.a == null) {
                StackedLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedLineSeriesDescriptionMetadata.c(StackedLineSeriesDescriptionMetadata.a);
            }
            if (a.j(StackedLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(StackedLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            StackedLineSeriesDescriptionMetadata.b(a);
            a.aa("StackedLineSeries", () => new StackedLineSeriesDescription());
            a.z("StackedLineSeries", StackedLineSeriesDescriptionMetadata.a);
        }
    }
    StackedLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedLineSeriesDescriptionMetadata, 'StackedLineSeriesDescriptionMetadata');
    StackedLineSeriesDescriptionMetadata.a = null;
    return StackedLineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StackedLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedLineSeriesDescription } from "./StackedLineSeriesDescription";
/**
 * @hidden
 */
export let StackedLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedLineSeriesDescriptionMetadata.a == null) {
                StackedLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedLineSeriesDescriptionMetadata.c(StackedLineSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(StackedLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            StackedLineSeriesDescriptionMetadata.b(a);
            a.ac("StackedLineSeries", () => new StackedLineSeriesDescription());
            a.ab("StackedLineSeries", StackedLineSeriesDescriptionMetadata.a);
        }
    }
    StackedLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedLineSeriesDescriptionMetadata, 'StackedLineSeriesDescriptionMetadata');
    StackedLineSeriesDescriptionMetadata.a = null;
    return StackedLineSeriesDescriptionMetadata;
})();
